--[[
Copyright 2014 Control4 Corporation.  All rights reserved.

+++ driver.lua +++
Entry point for lua execution
]]

require "intercom_proxy.intercom_debug"
require "intercom_proxy.intercom_constants"
require "intercom_proxy.intercom_notify"
require "intercom_proxy.intercom_command"
require "intercom_proxy.intercom_protocol"
require "intercom_proxy.intercom_test"

local init_timer_ = 0

-- Driver Version
function version()

   local maj = 1
   local min = 2
   local rev = 6
   local ver = string.format("%d.%d.%d", maj, min, rev)

   return ver
end

--[[
    C4 namespace callbacks
--]]

function OnDriverInit()

	if PersistData == nil then
	
		PersistData = {}
	end
	INTERCOM_DEBUG.DEBUG("OnDriverInit called")	
end

function OnDriverLateInit()
   
	--OnPropertyChanged("Username")
	init_timer_ = C4:AddTimer(10, "SECONDS")
	INTERCOM_DEBUG.DEBUG("OnDriverLateInit called")	         
end

function OnDriverDestroyed()
	
	INTERCOM_DEBUG.DEBUG("OnDriverDestroyed called")
	INTERCOM_DEBUG.END()
	
	init_timer_ = C4:KillTimer(init_timer_)
end

function OnTimerExpired(id_timer)
	
	INTERCOM_DEBUG.DEBUG("OnTimerExpired(" .. id_timer .. ")")

	if id_timer == INTERCOM_DEBUG.TIMER then
		
		INTERCOM_DEBUG.DEBUG("Turning Debug Mode Off (timer expired)")
		C4:UpdateProperty("Debug Mode", "Off")
		INTERCOM_DEBUG.END()
	elseif id_timer == init_timer_ then
		
		if PersistData then
			
			if PersistData["Username"] then
				
				C4:UpdateProperty("Username", PersistData["Username"])
				OnPropertyChanged("Username")				
			end
			if PersistData["Password"] then
				
				C4:UpdateProperty("Password", PersistData["Password"])
				OnPropertyChanged("Password")				
			end
			if PersistData["Camera Enabled"] then
				
				C4:UpdateProperty("Camera Enabled", PersistData["Camera Enabled"])
				OnPropertyChanged("Camera Enabled")				
			end
			init_timer_ = C4:KillTimer(init_timer_)
		end
	end
end

function OnPropertyChanged(str_property)
	
	INTERCOM_DEBUG.DEBUG("OnPropertyChanged: Property Name = " .. str_property .. "; Property Value = " .. Properties[str_property])

	if str_property == "Debug Mode" then
		
		if Properties[str_property] == "Off" then
			
			INTERCOM_DEBUG.PRINT = false
			INTERCOM_DEBUG.LOG = false
			INTERCOM_DEBUG.END()
		elseif Properties[str_property] == "Print" then

			INTERCOM_DEBUG.PRINT = true
			INTERCOM_DEBUG.LOG = false
			INTERCOM_DEBUG.START()
		elseif Properties[str_property] == "Log" then
			
			INTERCOM_DEBUG.PRINT = false
			INTERCOM_DEBUG.LOG = true
			INTERCOM_DEBUG.START()
		elseif Properties[str_property] == "Print and Log" then
			
			INTERCOM_DEBUG.PRINT = true
			INTERCOM_DEBUG.LOG = true
			INTERCOM_DEBUG.START()
		end	
	end 
	if str_property == "Username" or str_property == "Password" then
		
		local username = Properties["Username"]
		local password = Properties["Password"]
		PersistData["Username"] = username
		PersistData["Password"] = password
		NOTIFY.Sip_Username_Changed(username, password)
		INTERCOM_DEBUG.DEBUG("Username = " .. username .. "; Password = " .. password)
	end
	if str_property == "Camera Enabled" then
		
		local enabled = Properties["Camera Enabled"]
		PersistData["Camera Enabled"] = enabled		
		NOTIFY.Camera_Enabled_Changed(enabled)
		INTERCOM_DEBUG.DEBUG("Camera Enabled = " .. enabled)
	end
end

--[[
+++ ExecuteCommand +++
Purpose: Handle the ExecuteCommand
Params: str_command = the command
		t_params = parameters of command
]]
function ExecuteCommand(str_command, t_params)

	INTERCOM_DEBUG.DEBUG_COMMAND("ExecuteCommand", str_command, t_params)

	if str_command == "LUA_ACTION" then
		
		if t_params ~= nil then
			
			for param_name, param_value in pairs(t_params) do
				
				if param_name == "ACTION" then
				
					if param_value == "TEST_ONE" then
						
						INTERCOM_DEBUG.DEBUG("Executing Change State to Idle")
						INTERCOM_TEST.Test_State_Changed_Idle()
					end
					if param_value == "TEST_TWO" then
						
						INTERCOM_DEBUG.DEBUG("Executing Change State to NotReady")
						INTERCOM_TEST.Test_State_Changed_NotReady()
					end	
				end
			end
		end
	else

	end
end

--[[
+++ ReceivedFromProxy +++
Purpose: ReceivedFromProxy callback
Params: id = proxy ID (5001, 5002, etc)
		str_command = the command
		t_params = parameters of command
]]
function ReceivedFromProxy(id, str_command, t_params)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("ReceivedFromProxy", str_command, t_params)
	
	local cmd_handler = COMMAND_HANDLER[str_command]
	if cmd_handler ~= nil then
		
		cmd_handler(t_params)
	end
end

--[[
+++ OnConnectionStatusChanged +++
Purpose: OnConnectionStatusChanged callback
Params: id_binding = binding ID of the connection
		port = port of the connection
		str_status = status of the connection
]]
function OnConnectionStatusChanged(id_binding, port, str_status)
	
	INTERCOM_DEBUG.DEBUG("OnConnectionStatusChanged: ID Binding = " .. id_binding .. "; Port = " .. port .. "; Status = " .. str_status)	
end

--[[
+++ OnNetworkBindingChanged +++
Purpose: OnNetworkBindingChanged callback
Params: id_binding = binding ID that has changed
		bound = bound or unbound true/false
]]
function OnNetworkBindingChanged(id_binding, bound)

	local str_bound = "false"
	if bound then
		
		str_bound = "true"
	end
	
	INTERCOM_DEBUG.DEBUG("OnNetworkBindingChanged: ID Binding = " .. id_binding .. "; Bound = " .. str_bound)	
end

--[[
+++ ReceivedFromNetwork +++
Purpose: ReceivedFromNetwork callback
Params: id_binding = binding ID that has data on it
		port = that data came in on
		str_data = the data that was received
]]
function ReceivedFromNetwork(id_binding, port, str_data)	

	INTERCOM_DEBUG.DEBUG("ReceivedFromNetwork: ID Binding = " .. id_binding .. "; Port = " .. port .. "; Data = " .. str_data)	
end

-- Update the Version property
C4:UpdateProperty("Version", version())
