
--[[
Copyright 2014 Control4 Corporation.  All rights reserved.

+++ intercom_command.lua +++
Command Handling API for the Intercom Proxy
]]

COMMAND_HANDLER = {
	
	--[[
	+++ SET_RINGER_VOLUME +++
	Purpose: Handle the set ringer volume command
	Params: t_params[COMMAND_PARAM.RINGER_VOLUME_PARAM] = the new ringer volume
	]]
	SET_RINGER_VOLUME = function(t_params, binding_id)
		
		INTERCOM_DEBUG.DEBUG_COMMAND("COMMAND_HANDLER.SET_RINGER_VOLUME", "SET_RINGER_VOLUME", t_params)
		
		local val = t_params[COMMAND_PARAM.RINGER_VOLUME_PARAM]	
		if val ~= nil then
			
			-- %DRIVER_DEVELOPER%
			-- set local protocol value or send on to device here, 
			local protocol_params = {}
			PROTOCOL.SET_RINGER_VOLUME(protocol_params)
			-- then notify
			NOTIFY.Ringer_Volume_Changed(val, binding_id)		
			-- return the new value
			return val
		end
	end,
	
	--[[
	+++ SET_SPEAKER_VOLUME +++
	Purpose: Handle the set speaker volume command
	Params: t_params[COMMAND_PARAM.SPEAKER_VOLUME_PARAM] = the new speaker volume
	]]
	SET_SPEAKER_VOLUME = function(t_params, binding_id)
		
		INTERCOM_DEBUG.DEBUG_COMMAND("COMMAND_HANDLER.SET_SPEAKER_VOLUME", "SET_SPEAKER_VOLUME", t_params)
		
		local val = t_params[COMMAND_PARAM.SPEAKER_VOLUME_PARAM]	
		if val ~= nil then
			
			-- %DRIVER_DEVELOPER%
			-- set local protocol value or send on to device here, 
			local protocol_params = {}
			PROTOCOL.SET_SPEAKER_VOLUME(protocol_params)
			-- then notify
			NOTIFY.Speaker_Volume_Changed(val, binding_id)
			-- return the new value
			return val
		end
	end,
	
	--[[
	+++ SET_MICROPHONE_GAIN +++
	Purpose: Handle the set microphone gain command
	Params: t_params[COMMAND_PARAM.MICROPHONE_GAIN_PARAM] = the new microphone gain
	]]
	SET_MICROPHONE_GAIN = function(t_params, binding_id)
	
		INTERCOM_DEBUG.DEBUG_COMMAND("COMMAND_HANDLER.SET_MICROPHONE_GAIN", "SET_MICROPHONE_GAIN", t_params)
		
		local val = t_params[COMMAND_PARAM.MICROPHONE_GAIN_PARAM]	
		if val ~= nil then
			-- %DRIVER_DEVELOPER%
			-- set local protocol value or send on to device here,
			local protocol_params = {}
			PROTOCOL.SET_MICROPHONE_GAIN(protocol_params)
			-- then notify
			NOTIFY.Microphone_Gain_Changed(val, binding_id)		
			-- return the new value
			return val
		end
	end,
	
	--[[
	+++ START_CALL +++
	Purpose: Handle the start call command
	Params: t_params[COMMAND_PARAM.DEVICE_ID_PARAM] = the proxy ID of the caller
			t_params[COMMAND_PARAM.REMOTE_DEVICE_ID_PARAM] = the proxy ID of the callee
			t_params[COMMAND_PARAM.AUDIO_PARAM] = the requested audio cap for the call
			t_params[COMMAND_PARAM.VIDEO_PARAM] = the requested video cap for the call
			t_params[COMMAND_PARAM.RING_PARAM] = the ring param for the call
	]]
	START_CALL = function(t_params, binding_id)
		
		INTERCOM_DEBUG.DEBUG_COMMAND("COMMAND_HANDLER.START_CALL", "START_CALL", t_params)
	
		local device_id = t_params[COMMAND_PARAM.DEVICE_ID_PARAM]
		local remote_device_id = t_params[COMMAND_PARAM.REMOTE_DEVICE_ID_PARAM]
		local audio = t_params[COMMAND_PARAM.AUDIO_PARAM]
		local video = t_params[COMMAND_PARAM.VIDEO_PARAM]
		local ring = t_params[COMMAND_PARAM.RING_PARAM]
		
		-- %DRIVER_DEVELOPER%
		-- send start call params on to the device here
		local protocol_params = {}
		PROTOCOL.START_CALL(protocol_params)
	end,
	
	--[[
	+++ END_CALL +++
	Purpose: Handle the end call command
	Params: t_params[COMMAND_PARAM.DEVICE_ID_PARAM] = the proxy ID of the caller
			t_params[COMMAND_PARAM.REMOTE_DEVICE_ID_PARAM] = the proxy ID of the callee
			t_params[COMMAND_PARAM.SESSION_ID_PARAM] = the session ID of the call

	]]
	END_CALL = function(t_params, binding_id)
	
		INTERCOM_DEBUG.DEBUG_COMMAND("COMMAND_HANDLER.END_CALL", "END_CALL", t_params)
		
		local device_id = t_params[COMMAND_PARAM.DEVICE_ID_PARAM]
		local remote_device_id = t_params[COMMAND_PARAM.REMOTE_DEVICE_ID_PARAM]
		local session_id = t_params[COMMAND_PARAM.SESSION_ID_PARAM]
		
		-- %DRIVER_DEVELOPER%
		-- send end call params on to the device here
		local protocol_params = {}
		PROTOCOL.END_CALL(protocol_params)
	end,
	
	--[[
	+++ ACCEPT_CALL +++
	Purpose: Handle the accept call command
	Params: t_params[COMMAND_PARAM.DEVICE_ID_PARAM] = the proxy ID of the caller
			t_params[COMMAND_PARAM.REMOTE_DEVICE_ID_PARAM] = the proxy ID of the callee
			t_params[COMMAND_PARAM.SESSION_ID_PARAM] = the session ID of the call
			t_params[COMMAND_PARAM.AUDIO_PARAM] = the requested audio cap for the call
			t_params[COMMAND_PARAM.VIDEO_PARAM] = the requested video cap for the call
	]]
	ACCEPT_CALL = function(t_params, binding_id)
	
		INTERCOM_DEBUG.DEBUG_COMMAND("COMMAND_HANDLER.ACCEPT_CALL", "ACCEPT_CALL", t_params)
		
		local device_id = t_params[COMMAND_PARAM.DEVICE_ID_PARAM]
		local remote_device_id = t_params[COMMAND_PARAM.REMOTE_DEVICE_ID_PARAM]
		local session_id = t_params[COMMAND_PARAM.SESSION_ID_PARAM]
		local audio = t_params[COMMAND_PARAM.AUDIO_PARAM]
		local video = t_params[COMMAND_PARAM.VIDEO_PARAM]
				
		-- %DRIVER_DEVELOPER%
		-- send end call params on to the device here
		local protocol_params = {}
		PROTOCOL.ACCEPT_CALL(protocol_params)
	end,
	
	--[[
	+++ REJECT_CALL +++
	Purpose: Handle the reject call command
	Params: t_params[COMMAND_PARAM.DEVICE_ID_PARAM] = the proxy ID of the caller
			t_params[COMMAND_PARAM.REMOTE_DEVICE_ID_PARAM] = the proxy ID of the callee
			t_params[COMMAND_PARAM.SESSION_ID_PARAM] = the session ID of the call
	]]
	REJECT_CALL = function(t_params, binding_id)
	
		INTERCOM_DEBUG.DEBUG_COMMAND("COMMAND_HANDLER.REJECT_CALL", "REJECT_CALL", t_params)
		
		local device_id = t_params[COMMAND_PARAM.DEVICE_ID_PARAM]
		local session_id = t_params[COMMAND_PARAM.SESSION_ID_PARAM]
		local remote_device_id = t_params[COMMAND_PARAM.REMOTE_DEVICE_ID_PARAM]
				
		-- %DRIVER_DEVELOPER%
		-- send end call params on to the device here
		local protocol_params = {}
		PROTOCOL.REJECT_CALL(protocol_params)
	end,

	--[[
	+++ PAUSE_CALL +++
	Purpose: Handle the pause call command
	Params: t_params[COMMAND_PARAM.DEVICE_ID_PARAM] = the proxy ID of the cdevice
			t_params[COMMAND_PARAM.REMOTE_DEVICE_ID_PARAM] = the proxy ID of the remote device
			t_params[COMMAND_PARAM.SESSION_ID_PARAM] = the session ID of the call
	]]
	PAUSE_CALL = function(t_params, binding_id)
	
		INTERCOM_DEBUG.DEBUG_COMMAND("COMMAND_HANDLER.PAUSE_CALL", "PAUSE_CALL", t_params)
		
		local device_id = t_params[COMMAND_PARAM.DEVICE_ID_PARAM]
		local session_id = t_params[COMMAND_PARAM.SESSION_ID_PARAM]
		local remote_device_id = t_params[COMMAND_PARAM.REMOTE_DEVICE_ID_PARAM]
				
		-- %DRIVER_DEVELOPER%
		-- send end call params on to the device here
		local protocol_params = {}
		PROTOCOL.PAUSE_CALL(protocol_params)
	end,
	
	--[[
	+++ RESUME_CALL +++
	Purpose: Handle the resume call command
	Params: t_params[COMMAND_PARAM.DEVICE_ID_PARAM] = the proxy ID of the cdevice
			t_params[COMMAND_PARAM.REMOTE_DEVICE_ID_PARAM] = the proxy ID of the remote device
			t_params[COMMAND_PARAM.SESSION_ID_PARAM] = the session ID of the call
	]]
	RESUME_CALL = function(t_params, binding_id)
	
		INTERCOM_DEBUG.DEBUG_COMMAND("COMMAND_HANDLER.RESUME_CALL", "RESUME_CALL", t_params)
		
		local device_id = t_params[COMMAND_PARAM.DEVICE_ID_PARAM]
		local session_id = t_params[COMMAND_PARAM.SESSION_ID_PARAM]
		local remote_device_id = t_params[COMMAND_PARAM.REMOTE_DEVICE_ID_PARAM]
				
		-- %DRIVER_DEVELOPER%
		-- send end call params on to the device here
		local protocol_params = {}
		PROTOCOL.RESUME_CALL(protocol_params)
	end,
	
	--[[
	+++ START_MONITOR_CALL +++
	Purpose: Handle the start monitor call command
	Params: t_params[COMMAND_PARAM.DEVICE_ID_PARAM] = the proxy ID of the caller
			t_params[COMMAND_PARAM.REMOTE_DEVICE_ID_PARAM] = the proxy ID of the callee
			t_params[COMMAND_PARAM.AUDIO_PARAM] = the requested audio cap for the call
			t_params[COMMAND_PARAM.VIDEO_PARAM] = the requested video cap for the call
			t_params[COMMAND_PARAM.RING_PARAM] = the ring param for the call
	]]
	START_MONITOR_CALL = function(t_params, binding_id)
		
		INTERCOM_DEBUG.DEBUG_COMMAND("COMMAND_HANDLER.START_MONITOR_CALL", "START_MONITOR_CALL", t_params)
	
		local device_id = t_params[COMMAND_PARAM.DEVICE_ID_PARAM]
		local remote_device_id = t_params[COMMAND_PARAM.REMOTE_DEVICE_ID_PARAM]
		local audio = t_params[COMMAND_PARAM.AUDIO_PARAM]
		local video = t_params[COMMAND_PARAM.VIDEO_PARAM]
		local ring = t_params[COMMAND_PARAM.RING_PARAM]
		
		-- %DRIVER_DEVELOPER%
		-- send start call params on to the device here
		local protocol_params = {}
		PROTOCOL.START_MONITOR_CALL(protocol_params)
	end,
	
	--[[
	+++ START_BROADCAST_CALL +++
	Purpose: Handle the start monitor call command
	Params: t_params[COMMAND_PARAM.DEVICE_ID_PARAM] = the proxy ID of the caller
			t_params[COMMAND_PARAM.AUDIO_PARAM] = the requested audio cap for the call
			t_params[COMMAND_PARAM.VIDEO_PARAM] = the requested video cap for the call
			t_params[COMMAND_PARAM.GROUP_ID_PARAM] = the group ID of the group being called
	]]
	START_BROADCAST_CALL = function(t_params, binding_id)
		
		INTERCOM_DEBUG.DEBUG_COMMAND("COMMAND_HANDLER.START_BROADCAST_CALL", "START_BROADCAST_CALL", t_params)
	
		local device_id = t_params[COMMAND_PARAM.DEVICE_ID_PARAM]
		local audio = t_params[COMMAND_PARAM.AUDIO_PARAM]
		local video = t_params[COMMAND_PARAM.VIDEO_PARAM]
		local group_id = t_params[COMMAND_PARAM.GROUP_ID_PARAM]
		
		-- %DRIVER_DEVELOPER%
		-- send start call params on to the device here
		local protocol_params = {}
		PROTOCOL.START_BROADCAST_CALL(protocol_params)
	end,
	
	--[[
	+++ START_CUSTOM_CALL +++
	Purpose: Handle the start monitor call command
	Params: t_params[COMMAND_PARAM.DEVICE_ID_PARAM] = the proxy ID of the caller
			t_params[COMMAND_PARAM.AUDIO_PARAM] = the requested audio cap for the call
			t_params[COMMAND_PARAM.VIDEO_PARAM] = the requested video cap for the call
			t_params[COMMAND_PARAM.DEVICES_PARAM] = the devices in the custom call
	]]
	START_CUSTOM_CALL = function(t_params, binding_id)
		
		INTERCOM_DEBUG.DEBUG_COMMAND("COMMAND_HANDLER.START_CUSTOM_CALL", "START_CUSTOM_CALL", t_params)
	
		local device_id = t_params[COMMAND_PARAM.DEVICE_ID_PARAM]
		local audio = t_params[COMMAND_PARAM.AUDIO_PARAM]
		local video = t_params[COMMAND_PARAM.VIDEO_PARAM]
		local devices = t_params[COMMAND_PARAM.DEVICES_PARAM] -- should be a list of devices in the custom call
		
		-- %DRIVER_DEVELOPER%
		-- send start call params on to the device here
		local protocol_params = {}
		PROTOCOL.START_CUSTOM_CALL(protocol_params)
	end
}
