
--[[
Copyright 2014 Control4 Corporation.  All rights reserved.

+++ intercom_notify.lua +++
Notification API for the Intercom Proxy
]]


local DEFAULT_PROXY_BINDINGID = 5001

function send_notify(notify_name, t_params, binding_id)

	binding_id = binding_id or DEFAULT_PROXY_BINDINGID
	C4:SendToProxy(binding_id, notify_name, t_params, "NOTIFY")
end

--[[
+++ Intercom notifications: protocol --> proxy +++
]]

NOTIFY = {
	PROXY_ID = 5001 -- this was added after the template
}

--[[
+++ Current_State_Changed +++
Purpose: Notify when the state of the intercom has changed
Params: state = the new state/changed state of the intercom
]]
function NOTIFY.Current_State_Changed(state, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.CURRENT_STATE_PARAM] = state
	send_notify(NOTIFICATIONS.CURRENT_STATE_CHANGED_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Current_State_Changed", NOTIFICATIONS.CURRENT_STATE_CHANGED_NTF, t_params)
end

--[[
+++ Ringer_Volume_Changed +++
Purpose: Notify when the ringer volume of the intercom has changed
Params: level = the new ringer volume level of the intercom
]]
function NOTIFY.Ringer_Volume_Changed(level, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.RINGER_VOLUME_PARAM] = level
	send_notify(NOTIFICATIONS.RINGER_VOLUME_CHANGED_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Ringer_Volume_Changed", NOTIFICATIONS.RINGER_VOLUME_CHANGED_NTF, t_params)
end

--[[
+++ Speaker_Volume_Changed +++
Purpose: Notify when the speaker volume of the intercom has changed
Params: level = the new speaker volume level of the intercom
]]
function NOTIFY.Speaker_Volume_Changed(level, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.SPEAKER_VOLUME_PARAM] = level
	send_notify(NOTIFICATIONS.SPEAKER_VOLUME_CHANGED_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Speaker_Volume_Changed", NOTIFICATIONS.SPEAKER_VOLUME_CHANGED_NTF, t_params)
end

--[[
+++ Microphone_Gain_Changed +++
Purpose: Notify when the microphone gain of the intercom has changed
Params: gain = the new microphone gain of the intercom
]]
function NOTIFY.Microphone_Gain_Changed(gain, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.MICROPHONE_GAIN_PARAM] = gain
	send_notify(NOTIFICATIONS.MICROPHONE_GAIN_CHANGED_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Microphone_Gain_Changed", NOTIFICATIONS.MICROPHONE_GAIN_CHANGED_NTF, t_params)
end

--[[
+++ Call_Ended +++
Purpose: Notify when the call has ended
Params: device_id = the device ID of the proxy
		session_id = the session ID of the SIP session
		hangup_type = the hang up type (how the call was ended)
]]
function NOTIFY.Call_Ended(device_id, session_id, hangup_type, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.DEVICE_ID_PARAM] = device_id
	t_params[NOTIFICATION_PARAM.SESSION_ID_PARAM] = session_id
	t_params[NOTIFICATION_PARAM.HANGUP_TYPE_PARAM] = hangup_type
	send_notify(NOTIFICATIONS.CALL_ENDED_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Call_Ended", NOTIFICATIONS.CALL_ENDED_NTF, t_params)
end

--[[
+++ Outgoing_Call +++
Purpose: Notify when the call is outgoing
Params: device_id = the device ID of the proxy
		session_id = the session ID of the SIP session
		call_type = the call type
		remote_device_id = the proxy ID of the remote endpoint
		audio = value of the audio cap
		video = value of the video cap
]]
function NOTIFY.Outgoing_Call(device_id, session_id, call_type, remote_device_id, audio, video, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.DEVICE_ID_PARAM] = device_id
	t_params[NOTIFICATION_PARAM.SESSION_ID_PARAM] = session_id
	t_params[NOTIFICATION_PARAM.CALL_TYPE_PARAM] = call_type
	t_params[NOTIFICATION_PARAM.REMOTE_DEVICE_ID_PARAM] = remote_device_id
	t_params[NOTIFICATION_PARAM.AUDIO_PARAM] = audio
	t_params[NOTIFICATION_PARAM.VIDEO_PARAM] = video
	send_notify(NOTIFICATIONS.OUTGOING_CALL_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Outgoing_Call", NOTIFICATIONS.OUTGOING_CALL_NTF, t_params)
end

--[[
+++ Incoming_Call +++
Purpose: Notify when there is a call incoming
Params: device_id = the device ID of the proxy
		session_id = the session ID of the SIP session
		call_type = the call type
		remote_device_id = the proxy ID of the remote endpoint
		audio = value of the audio cap
		video = value of the video cap
]]
function NOTIFY.Incoming_Call(device_id, session_id, call_type, remote_device_id, audio, video, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.DEVICE_ID_PARAM] = device_id
	t_params[NOTIFICATION_PARAM.SESSION_ID_PARAM] = session_id
	t_params[NOTIFICATION_PARAM.CALL_TYPE_PARAM] = call_type
	t_params[NOTIFICATION_PARAM.REMOTE_DEVICE_ID_PARAM] = remote_device_id
	t_params[NOTIFICATION_PARAM.AUDIO_PARAM] = audio
	t_params[NOTIFICATION_PARAM.VIDEO_PARAM] = video
	send_notify(NOTIFICATIONS.INCOMING_CALL_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Incoming_Call", NOTIFICATIONS.INCOMING_CALL_NTF, t_params)
end

--[[
+++ Call_Accepted +++
Purpose: Notify when the incoming call has been accepted
Params: device_id = the device ID of the proxy
		session_id = the session ID of the SIP session
		audio = value of the audio cap
		video = value of the video cap
]]
function NOTIFY.Call_Accepted(device_id, session_id, audio, video, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.DEVICE_ID_PARAM] = device_id
	t_params[NOTIFICATION_PARAM.SESSION_ID_PARAM] = session_id
	t_params[NOTIFICATION_PARAM.AUDIO_PARAM] = audio
	t_params[NOTIFICATION_PARAM.VIDEO_PARAM] = video
	send_notify(NOTIFICATIONS.CALL_ACCEPTED_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Call_Accepted", NOTIFICATIONS.CALL_ACCEPTED_NTF, t_params)
end

--[[
+++ Call_Rejected +++
Purpose: Notify when the incoming call has been rejected
Params: device_id = the device ID of the proxy
		session_id = the session ID of the SIP session
		hangup_type = the hang up type (how the call was ended)
]]
function NOTIFY.Call_Rejected(device_id, session_id, hangup_type, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.DEVICE_ID_PARAM] = device_id
	t_params[NOTIFICATION_PARAM.SESSION_ID_PARAM] = session_id
	t_params[NOTIFICATION_PARAM.HANGUP_TYPE_PARAM] = hangup_type
	send_notify(NOTIFICATIONS.CALL_REJECTED_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Call_Rejected", NOTIFICATIONS.CALL_REJECTED_NTF, t_params)
end

--[[
+++ Call_Paused +++
Purpose: Notify when the call has been paused/ put on hold
Params: device_id = the device ID of the proxy
		session_id = the session ID of the SIP session
]]
function NOTIFY.Call_Paused(device_id, session_id, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.DEVICE_ID_PARAM] = device_id
	t_params[NOTIFICATION_PARAM.SESSION_ID_PARAM] = session_id
	send_notify(NOTIFICATIONS.CALL_PAUSED_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Call_Paused", NOTIFICATIONS.CALL_PAUSED_NTF, t_params)
end

--[[
+++ Call_Resumed +++
Purpose: Notify when the call has been resumed from a paused state
Params: device_id = the device ID of the proxy
		session_id = the session ID of the SIP session
]]
function NOTIFY.Call_Resumed(device_id, session_id, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.DEVICE_ID_PARAM] = device_id
	t_params[NOTIFICATION_PARAM.SESSION_ID_PARAM] = session_id
	send_notify(NOTIFICATIONS.CALL_RESUMED_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Call_Resumed", NOTIFICATIONS.CALL_RESUMED_NTF, t_params)
end

--[[
+++ Camera_Enabled_Changed +++
Purpose: Notify when the camera enabled value of the intercom has changed
Params: enabled = the new enabled value (true/false) of the intercom
]]
function NOTIFY.Camera_Enabled_Changed(enabled, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.CAMERA_ENABLED_PARAM] = enabled
	send_notify(NOTIFICATIONS.CAMERA_ENABLED_CHANGED_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Camera_Enabled_Changed", NOTIFICATIONS.CAMERA_ENABLED_CHANGED_NTF, t_params)
end

--[[
+++ Conservative_AEC_Changed +++
Purpose: Notify when the conservative aec enabled value of the intercom has changed
Params: enabled = the new enabled value (true/false) of the intercom
]]
function NOTIFY.Conservative_AEC_Changed(enabled, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.AEC_ENABLED_PARAM] = enabled
	send_notify(NOTIFICATIONS.CONSERVATIVE_AEC_CHANGED_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Conservative_AEC_Changed", NOTIFICATIONS.CONSERVATIVE_AEC_CHANGED_NTF, t_params)
end

--[[
+++ Mute_Audio_Changed +++
Purpose: Notify when the audio muted value of the intercom has changed
Params: enabled = the new enabled value (true/false) of the intercom
]]
function NOTIFY.Mute_Audio_Changed(enabled, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.MUTE_AUDIO_PARAM] = enabled
	send_notify(NOTIFICATIONS.MUTE_AUDIO_CHANGED_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Mute_Audio_Changed", NOTIFICATIONS.MUTE_AUDIO_CHANGED_NTF, t_params)
end

--[[
+++ Use_Camera_Changed +++
Purpose: Notify when the use camera value of the intercom has changed
Params: enabled = the new enabled value (true/false) of the intercom
]]
function NOTIFY.Use_Camera_Changed(enabled, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.USE_CAMERA_PARAM] = enabled
	send_notify(NOTIFICATIONS.USE_CAMERA_CHANGED_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Use_Camera_Changed", NOTIFICATIONS.USE_CAMERA_CHANGED_NTF, t_params)
end

--[[
+++ Sip_Username_Changed +++
Purpose: Notify when the SIP username value of the intercom has changed
Params: username = the new username value of the intercom
]]
function NOTIFY.Sip_Username_Changed(username, password, binding_id)
	
	local t_params = {}
	t_params[NOTIFICATION_PARAM.USER_NAME_PARAM] = username
	if password then
		
		t_params[NOTIFICATION_PARAM.PASSWORD_PARAM] = password
	end
	send_notify(NOTIFICATIONS.SIP_USERNAME_CHANGED_NTF, t_params, binding_id)
	
	INTERCOM_DEBUG.DEBUG_COMMAND("NOTIFY.Sip_Username_Changed", NOTIFICATIONS.SIP_USERNAME_CHANGED_NTF, t_params)
end