
--[[
Copyright 2014 Control4 Corporation.  All rights reserved.

+++ intercom_protocol.lua +++
Protocol interface to the intercom device
]]

--[[
Use the INTERCOM namespace to implement device level communication
]]
INTERCOM = {
	NET_BINDING = 6001,
	PORT = 6700
}

--[[
Stubbed version for sending a message to the intercom
]]
function INTERCOM.send_to_intercom(data)

	if data ~= nil then
		
		data = data .. CRLF
		C4:SendToNetwork(INTERCOM.NET_BINDING, INTERCOM.PORT, data)
	end
end

PROTOCOL = {
	
	--[[
	+++ SET_RINGER_VOLUME +++
	Purpose: Issue a ringer volume setting to the intercom device
	Params: proto_params = parameters for setting the volume
	]]
	SET_RINGER_VOLUME = function(proto_params)
	
		INTERCOM_DEBUG.DEBUG_COMMAND("PROTOCOL.SET_RINGER_VOLUME", "SET_RINGER_VOLUME", proto_params)
		
		local data = nil -- C4.RV.SET 75
		INTERCOM.send_to_intercom(data)
	end,
	
	--[[
	+++ SET_SPEAKER_VOLUME +++
	Purpose: Issue a speaker volume setting to the intercom device
	Params: proto_params = parameters for setting the volume
	]]
	SET_SPEAKER_VOLUME = function(proto_params)
		
		INTERCOM_DEBUG.DEBUG_COMMAND("PROTOCOL.SET_SPEAKER_VOLUME", "SET_SPEAKER_VOLUME", proto_params)
		
		local data = nil
		INTERCOM.send_to_intercom(data)
	end,
	
	--[[
	+++ SET_MICROPHONE_GAIN +++
	Purpose: Issue a microphone gain setting to the intercom device
	Params: proto_params = parameters for setting the gain
	]]
	SET_MICROPHONE_GAIN = function(proto_params)
		
		INTERCOM_DEBUG.DEBUG_COMMAND("PROTOCOL.SET_MICROPHONE_GAIN", "SET_MICROPHONE_GAIN", proto_params)
		
		local data = nil
		INTERCOM.send_to_intercom(data)
	end,
	
	--[[
	+++ START_CALL +++
	Purpose: Issue a start call to the intercom device
	Params: proto_params = parameters required for starting a call on the intercom
	]]
	START_CALL = function(proto_params)
		
		INTERCOM_DEBUG.DEBUG_COMMAND("PROTOCOL.START_CALL", "START_CALL", proto_params)
		
		local data = nil
		INTERCOM.send_to_intercom(data)
	end,
	
	--[[
	+++ END_CALL +++
	Purpose: Issue an end call to the intercom device
	Params: proto_params = parameters required for ending a call on the intercom
	]]
	END_CALL = function(t_params, binding_id)
	
		INTERCOM_DEBUG.DEBUG_COMMAND("PROTOCOL.END_CALL", "END_CALL", proto_params)
		
		local data = nil
		INTERCOM.send_to_intercom(data)
	end,
	
	--[[
	+++ ACCEPT_CALL +++
	Purpose: Issue an accept call to the intercom device
	Params: proto_params = parameters required for accepting a call on the intercom
	]]
	ACCEPT_CALL = function(t_params, binding_id)
	
		INTERCOM_DEBUG.DEBUG_COMMAND("PROTOCOL.ACCEPT_CALL", "ACCEPT_CALL", proto_params)
		
		local data = nil
		INTERCOM.send_to_intercom(data)
	end,
	
	--[[
	+++ REJECT_CALL +++
	Purpose: Issue a reject call to the intercom device
	Params: proto_params = parameters required for rejecting a call on the intercom
	]]
	REJECT_CALL = function(t_params, binding_id)
	
		INTERCOM_DEBUG.DEBUG_COMMAND("PROTOCOL.REJECT_CALL", "REJECT_CALL", proto_params)
		
		local data = nil
		INTERCOM.send_to_intercom(data)
	end,
	
	--[[
	+++ PAUSE_CALL +++
	Purpose: Issue a pause call to the intercom device
	Params: proto_params = parameters required for pausing a call on the intercom
	]]
	PAUSE_CALL = function(t_params, binding_id)
	
		INTERCOM_DEBUG.DEBUG_COMMAND("PROTOCOL.PAUSE_CALL", "PAUSE_CALL", proto_params)
		
		local data = nil
		INTERCOM.send_to_intercom(data)
	end,
	
	--[[
	+++ RESUME_CALL +++
	Purpose: Issue a pause call to the intercom device
	Params: proto_params = parameters required for resuming a paused call on the intercom
	]]
	RESUME_CALL = function(t_params, binding_id)
	
		INTERCOM_DEBUG.DEBUG_COMMAND("PROTOCOL.RESUME_CALL", "RESUME_CALL", proto_params)
		
		local data = nil
		INTERCOM.send_to_intercom(data)
	end,
	
	--[[
	+++ START_MONITOR_CALL +++
	Purpose: Issue a start call to the intercom device
	Params: proto_params = parameters required for starting a monitor call on the intercom
	]]
	START_MONITOR_CALL = function(proto_params)
		
		INTERCOM_DEBUG.DEBUG_COMMAND("PROTOCOL.START_MONITOR_CALL", "START_MONITOR_CALL", proto_params)
		
		local data = nil
		INTERCOM.send_to_intercom(data)
	end,
	
	--[[
	+++ START_BROADCAST_CALL +++
	Purpose: Issue a start broadcast call to the intercom device
	Params: proto_params = parameters required for starting a broadcast call on the intercom
	]]
	START_BROADCAST_CALL = function(proto_params)
		
		INTERCOM_DEBUG.DEBUG_COMMAND("PROTOCOL.START_BROADCAST_CALL", "START_BROADCAST_CALL", proto_params)
		
		local data = nil
		INTERCOM.send_to_intercom(data)
	end,
	
	--[[
	+++ START_CUSTOM_CALL +++
	Purpose: Issue a start custom call to the intercom device
	Params: proto_params = parameters required for starting a custom call on the intercom
	]]
	START_CUSTOM_CALL = function(proto_params)
		
		INTERCOM_DEBUG.DEBUG_COMMAND("PROTOCOL.START_CUSTOM_CALL", "START_CUSTOM_CALL", proto_params)
		
		local data = nil
		INTERCOM.send_to_intercom(data)
	end
}